@@ -8,7 +8,7 @@ from xmlApiParse.enums import SpecificCollectionsEnum, AllCollectionsEnum
 from xmlApiParse.repository import (
     ParseError, ConnectionErrors, BadRequestError,
     WaiterListDTO, OrderListDTO, RestaurantsDTO,
-    MenuDTO, MenuItemsDTO, EmployeeDTO
+    MenuDTO, MenuItemsDTO, EmployeeDTO, WaiterDTO
 )
 
 
@@ -152,20 +152,26 @@ class RKXMLRequest(XMLRequest):
         element = []
         try:
             tree = Etree.fromstring(response.content)
-            parsed_employees_list = tree.findall(
-                "./RK7Reference/RIChildItems/TRK7Restaurant/RIChildItems/TRole/RIChildItems/TEmployee")
-            for employee in parsed_employees_list:
-                if employee.attrib["Name"] == name_filter:
-                    return employee.attrib
-                if name_filter is None:
-                    name = employee.attrib['Name']
-                    altname = employee.attrib['AltName']
-                    gen_san_date = employee.attrib['genSanDate']
-                    gen_tax_payer_id_num = employee.attrib['genTaxPayerIdNum']
-                    ident = employee.attrib['Ident']
-                    employee_dto = EmployeeDTO(name=name, altname=altname, gen_san_date=gen_san_date,
-                                            gen_tax_payer_id_num=gen_tax_payer_id_num, ident=ident)
-                    element.append(employee_dto)
+            for item in tree.findall("./RK7Reference/RIChildItems/TRK7Restaurant"):
+                restaurant = item.attrib['Name']
+                for item in tree.findall(
+                        "./RK7Reference/RIChildItems/TRK7Restaurant/RIChildItems/TRole"):
+                    role = item.attrib['Name']
+                    for item in tree.findall(
+                        "./RK7Reference/RIChildItems/TRK7Restaurant/RIChildItems/TRole/RIChildItems/TEmployee"
+                    ):
+                        if item.attrib["Name"] == name_filter:
+                            return item.attrib
+                        if name_filter is None:
+                            name = item.attrib['Name']
+                            altname = item.attrib['AltName']
+                            gen_san_date = item.attrib['genSanDate']
+                            gen_tax_payer_id_num = item.attrib['genTaxPayerIdNum']
+                            ident = item.attrib['Ident']
+                            employee_dto = EmployeeDTO(restaurant=restaurant, name=name, role=role, altname=altname,
+                                                    gen_san_date=gen_san_date, ident=ident,
+                                                    gen_tax_payer_id_num=gen_tax_payer_id_num)
+                            element.append(employee_dto)
         except (ParseError, ValueError) as error:
             raise ParseError(f"XML parse error - {str(error)}")
         return element
@@ -284,3 +290,28 @@ class RKXMLRequest(XMLRequest):
         except Exception as error:
             raise ParseError(f"XML parse error - {str(error)}")
         return element
+
+    def get_waiter(self) -> List[WaiterDTO]:
+        body = '<RK7Query> <RK7CMD CMD="GetRefData" RefName="Restaurants" ' \
+                             'IgnoreEnums="1" WithChildItems="3" WithMacroProp="1" ' \
+                             'OnlyActive = "1" PropMask="RIChildItems.(Ident,Name,genRestIP,genprnStation,' \
+                             'genDefDlvCurrency,AltName,RIChildItems.TRole(ItemIdent,passdata,Name,AltName,gen*,' \
+                             'RIChildItems.(Code,Ident,Name,AltName,gen*)))" /></RK7Query>'
+
+        response = self.send_request(body=body)
+        parsed_waiter_nodes = Etree.fromstring(response.content)
+        data = []
+        for item in parsed_waiter_nodes.findall("./RK7Reference/RIChildItems/TRK7Restaurant"):
+            restaurant = item.attrib['Name']
+            for item in parsed_waiter_nodes.findall(
+                    "./RK7Reference/RIChildItems/TRK7Restaurant/RIChildItems/TRole"):
+                if item.attrib['Name'] == "Официанты":
+                    for item in parsed_waiter_nodes.findall(
+                        "./RK7Reference/RIChildItems/TRK7Restaurant/RIChildItems/TRole/RIChildItems/TEmployee"
+                    ):
+                        waiter_dto = WaiterDTO(
+                            restaurant=(restaurant),
+                            name=(item.attrib['Name']), ident=(item.attrib['Ident']),
+                            code=item.attrib['Code'])
+                        data.append(waiter_dto)
+        return data
